/** When your routing table is too long, you can split it into small modules **/

import Layout from '@/layout'

const wechatRouter = {
  path: '/wechat',
  component: Layout,
  redirect: '/wechat/caimei',
  alwaysShow: true, // will always show the root menu
  name: 'WeChat', // name必须和后台配置一致，不然匹配不到
  meta: { title: '微信后台', icon: 'wechat' },
  children: [
    {
      path: 'caimei',
      redirect: '/wechat/caimei/menus',
      name: 'WeChatCaimei',
      meta: { title: '采美网公众号', icon: 'component' },
      children: [
        {
          path: 'menus',
          component: () => import('@/views/wechat/caimei/menus/index'),
          name: 'WeChatCmMenus',
          meta: { title: '菜单管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/caimei/menus/list.vue'),
              name: 'WeChatCmMenuList',
              meta: { title: '菜单列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/caimei/menus/form.vue'),
              name: 'WeChatCmMenuEdit',
              meta: { title: '编辑菜单' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/caimei/menus/form.vue'),
              name: 'WeChatCmMenuEdit',
              meta: { title: '添加菜单' }
            }
          ]
        },
        {
          path: 'reply',
          component: () => import('@/views/wechat/caimei/reply/index'),
          name: 'WeChatCmReply',
          meta: { title: '回复配置' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/caimei/reply/list.vue'),
              name: 'WeChatCmReplyList',
              meta: { title: '回复配置列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/caimei/reply/form.vue'),
              name: 'WeChatCmReplyEdit',
              meta: { title: '编辑回复配置' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/caimei/reply/form.vue'),
              name: 'WeChatCmReplyEdit',
              meta: { title: '添加回复配置' }
            }
          ]
        },
        {
          path: 'text',
          component: () => import('@/views/wechat/caimei/text/index'),
          name: 'WeChatCmText',
          meta: { title: '文本素材管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/caimei/text/list.vue'),
              name: 'WeChatCmTextList',
              meta: { title: '文本素材列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/caimei/text/form.vue'),
              name: 'WeChatCmTextEdit',
              meta: { title: '编辑文本素材' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/caimei/text/form.vue'),
              name: 'WeChatCmTextEdit',
              meta: { title: '添加文本素材' }
            }
          ]
        },
        {
          path: 'image',
          component: () => import('@/views/wechat/caimei/image/index'),
          name: 'WeChatCmImage',
          meta: { title: '图文素材管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/caimei/image/list.vue'),
              name: 'WeChatCmImageList',
              meta: { title: '图文素材列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/caimei/image/form.vue'),
              name: 'WeChatCmImageEdit',
              meta: { title: '编辑图文素材' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/caimei/image/form.vue'),
              name: 'WeChatCmImageEdit',
              meta: { title: '添加图文素材' }
            }
          ]
        }
      ]
    },
    {
      path: 'hehe',
      redirect: '/wechat/hehe/menus',
      name: 'WeChatHehe',
      meta: { title: '呵呵商城公众号', icon: 'component' },
      children: [
        {
          path: 'menus',
          component: () => import('@/views/wechat/hehe/menus/index'),
          name: 'WeChatHeMenus',
          meta: { title: '菜单管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/hehe/menus/list.vue'),
              name: 'WeChatHeMenuList',
              meta: { title: '菜单列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/hehe/menus/form.vue'),
              name: 'WeChatHeMenuEdit',
              meta: { title: '编辑菜单' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/hehe/menus/form.vue'),
              name: 'WeChatHeMenuEdit',
              meta: { title: '添加菜单' }
            }
          ]
        },
        {
          path: 'reply',
          component: () => import('@/views/wechat/hehe/reply/index'),
          name: 'WeChatHeReply',
          meta: { title: '回复配置' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/hehe/reply/list.vue'),
              name: 'WeChatHeReplyList',
              meta: { title: '回复配置列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/hehe/reply/form.vue'),
              name: 'WeChatHeReplyEdit',
              meta: { title: '编辑回复配置' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/hehe/reply/form.vue'),
              name: 'WeChatHeReplyEdit',
              meta: { title: '添加回复配置' }
            }
          ]
        },
        {
          path: 'text',
          component: () => import('@/views/wechat/hehe/text/index'),
          name: 'WeChatHeText',
          meta: { title: '文本素材管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/hehe/text/list.vue'),
              name: 'WeChatHeTextList',
              meta: { title: '文本素材列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/hehe/text/form.vue'),
              name: 'WeChatHeTextEdit',
              meta: { title: '编辑文本素材' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/hehe/text/form.vue'),
              name: 'WeChatHeTextEdit',
              meta: { title: '添加文本素材' }
            }
          ]
        },
        {
          path: 'image',
          component: () => import('@/views/wechat/hehe/image/index'),
          name: 'WeChatHeImage',
          meta: { title: '图文素材管理' },
          children: [
            {
              path: 'list',
              hidden: true,
              component: () => import('@/views/wechat/hehe/image/list.vue'),
              name: 'WeChatHeImageList',
              meta: { title: '图文素材列表' }
            },
            {
              path: 'edit',
              hidden: true,
              component: () => import('@/views/wechat/hehe/image/form.vue'),
              name: 'WeChatHeImageEdit',
              meta: { title: '编辑图文素材' }
            },
            {
              path: 'add',
              hidden: true,
              component: () => import('@/views/wechat/hehe/image/form.vue'),
              name: 'WeChatHeImageEdit',
              meta: { title: '添加图文素材' }
            }
          ]
        }
      ]
    }
  ]
}
export default wechatRouter
